@@ -1,4 +1,4 @@
-// $Id: dbgmainwnd.cpp,v 1.50.2.1 2001/12/29 20:12:16 jsixt Exp $
+// $Id: dbgmainwnd.cpp,v 1.50.2.2 2002/01/31 20:14:03 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -205,8 +205,8 @@ void DebuggerMainWnd::initMenu()
     m_menuFile->insertItem(i18n("&Global Options..."), ID_FILE_GLOBAL_OPTIONS);
     m_menuFile->insertSeparator();
     m_menuFile->insertItem(i18n("&Quit"), ID_FILE_QUIT);
-    m_menuFile->setAccel(keys->open(), ID_FILE_OPEN);
-    m_menuFile->setAccel(keys->quit(), ID_FILE_QUIT);
+    m_menuFile->setAccel(KStdAccel::open(), ID_FILE_OPEN);
+    m_menuFile->setAccel(KStdAccel::quit(), ID_FILE_QUIT);
 
     m_menuView = new QPopupMenu;
     m_menuView->setCheckable(true);
@@ -224,7 +224,7 @@ void DebuggerMainWnd::initMenu()
     m_menuView->insertSeparator();
     m_menuView->insertItem(i18n("Toggle &Toolbar"), ID_VIEW_TOOLBAR);
     m_menuView->insertItem(i18n("Toggle &Statusbar"), ID_VIEW_STATUSBAR);
-    m_menuView->setAccel(keys->find(), ID_VIEW_FINDDLG);
+    m_menuView->setAccel(KStdAccel::find(), ID_VIEW_FINDDLG);
 
     m_menuProgram = new QPopupMenu;
     m_menuProgram->insertItem(i18n("&Run"), ID_PROGRAM_RUN);
