@@ -1,4 +1,4 @@
-// $Id: main.cpp,v 1.21.2.1 2001/12/29 20:12:16 jsixt Exp $
+// $Id: main.cpp,v 1.21.2.3 2002/03/09 21:25:24 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -17,7 +17,6 @@
 #else // QT_VERSION < 200
 #include <kmsgbox.h>
 #endif
-#include <kstdaccel.h>
 #include <kmenubar.h>
 #include "dbgmainwnd.h"
 #include "typetable.h"
@@ -68,7 +67,8 @@ int main(int argc, char** argv)
 	{ "t <file>", I18N_NOOP("transcript of conversation with the debugger"), 0 },
 	{ "r <device>", I18N_NOOP("remote debugging via <device>"), 0 },
 	{ "+[program]", I18N_NOOP("path of executable to debug"), 0 },
-	{ "+[core]", I18N_NOOP("a core file to use"), 0}
+	{ "+[core]", I18N_NOOP("a core file to use"), 0},
+	{ 0, 0, 0 }
     };
     KCmdLineArgs::addCmdLineOptions(options);
     
@@ -77,8 +77,6 @@ int main(int argc, char** argv)
     KGlobal::dirs()->addResourceType("types", "share/apps/kdbg/types");
 #endif
 
-    keys = new KStdAccel();
-
     DebuggerMainWnd debugger("kdbg_main");
 
     // insert help menu
