@@ -1,4 +1,4 @@
-// $Id: mainwndbase.h,v 1.16 2000/07/31 20:40:25 jsixt Exp $
+// $Id: mainwndbase.h,v 1.16.2.1 2002/01/31 20:14:03 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -16,14 +16,10 @@
 class KDebugger;
 class TTYWindow;
 class UpdateUI;
-class KStdAccel;
 class KToolBar;
 class KStatusBar;
 class KProcess;
 
-extern KStdAccel* keys;
-
-
 class WatchWindow : public QWidget
 {
     Q_OBJECT
