@@ -1,4 +1,4 @@
-// $Id: winstack.cpp,v 1.41 2000/11/11 11:12:29 jsixt Exp $
+// $Id: winstack.cpp,v 1.41.2.1 2001/12/09 19:06:23 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -190,6 +190,14 @@ bool WinStack::activatePath(QString pathName, int lineNo, const DbgAddr& address
     if (fw == 0) {
 	// not found, load it
 	fw = new SourceWindow(pathName, this, "fileWindow");
+
+	// slurp the file in
+	if (!fw->loadFile()) {
+	    // read failed
+	    delete fw;
+	    return false;
+	}
+
 	m_fileList.insert(0, fw);
 	connect(fw, SIGNAL(lineChanged()),SIGNAL(lineChanged()));
 	connect(fw, SIGNAL(clickedLeft(const QString&,int,const DbgAddr&,bool)),
@@ -213,9 +221,6 @@ bool WinStack::activatePath(QString pathName, int lineNo, const DbgAddr& address
 
 	changeWindowMenu();
 	
-	// slurp the file in
-	fw->loadFile();
-	
 	// set PC if there is one
 	emit newFileLoaded();
 	if (m_pcLine >= 0) {
